#Topsis-Ayush-101903749
Multiple criteria decision making (MCDM) using TOPSIS

## Installation
```pip install topsis-AYUSH-101903749```

##Sample Use case
import topsis-AYUSH-101903749 as t
t.topsis("input.csv","1,2,1,2,3","+,+,-,+,-","output.csv")

